@@ -1,12 +1,15 @@
 use std::fmt::Debug;
 
-use crate::data::{Chapter, Manga, Param, Source, ExtensionResult};
+use crate::data::{Chapter, Manga, Param, Source, ExtensionResult, Filters};
 
 /// `Extension` trait is an implementation for building extensions
 pub trait Extension: Send + Sync {
     /// Returns the information of the source
     fn detail(&self) -> Source;
 
+    /// Returns filter supported by the source
+    fn filters(&self) -> ExtensionResult<Option<Filters>>;
+
     /// Returns list of manga from the source
     ///
     /// # Arguments
@@ -30,7 +33,7 @@ pub trait Extension: Send + Sync {
     fn get_pages(&self, path: String) -> ExtensionResult<Vec<String>>;
 
     // /// Proxy image
-    // fn get_page(&self, url: &String) -> Result<Vec<u8>, Box<dyn Error>> {
+    // fn get_page(&self, url: &str) -> Result<Vec<u8>, Box<dyn Error>> {
     //     let bytes = {
     //         let resp = ureq::get(url).call()?;
     //         let mut reader = resp.into_reader();
